@@ -1,4 +1,6 @@
-# SPDX-License-Identifier: EUPL-1.2
+# SPDX-License-Identifier: MIT
+
+import platform
 
 import pytest
 
@@ -35,3 +37,12 @@ def test_unsupported_dynamic(package_unsupported_dynamic):
     with pytest.raises(mesonpy.MesonBuilderError, match='Unsupported dynamic fields: dependencies'):
         with mesonpy.Project.with_temp_working_dir():
             pass
+
+
+def test_unsupported_python_version(package_unsupported_python_version):
+    with pytest.raises(mesonpy.MesonBuilderError, match=(
+        f'Unsupported Python version `{platform.python_version()}`, '
+        'expected `==1.0.0`'
+    )):
+        with mesonpy.Project.with_temp_working_dir():
+            pass
